==> haskell-src-exts-util-0.2.5-317-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-K8jXuzTZtLGCBKreDC1Bez
key:                  haskell-src-exts-util-0.2.5-K8jXuzTZtLGCBKreDC1Bez
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  c2bf2d1ce24230fa4fb1f9f6de187f50
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-K8jXuzTZtLGCBKreDC1Bez
depends:
    base-4.16.4.0 containers-0.6.5.1
    data-default-0.7.1.1-5ZDwKrRtuQLAGjVA8Z3KJ8
    haskell-src-exts-1.23.1-8PbOqgcZbUgHyi9dZVDRl6 transformers-0.5.6.2
    uniplate-1.6.13-3WBI2JSXgJFJjO8ZIoMLz8

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-GvrXfbYa6IQ71Wk5jDm5S4
key:                  haskell-src-exts-util-0.2.5-GvrXfbYa6IQ71Wk5jDm5S4
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  59cf6510c574171824c0557f2e066880
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-GvrXfbYa6IQ71Wk5jDm5S4
depends:
    base-4.16.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    haskell-src-exts-1.23.1-JK67JKeYxaNH6wBMSbNzM2 transformers-0.5.6.2
    uniplate-1.6.13-E9XLtnRxE39Lc36BhbYiEq

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
